@@ -9,19 +9,18 @@ SPVM::IO::Socket::IP - IPv4/IPv6 Sockets
 =head1 Usage
 
   use IO::Socket::IP;
-  use Sys::Socket;
   use Sys::Socket::Constant as SOCKET;
   
   # Client Socket
   my $host = "www.perl.org";
   my $port = 80;
-  my $io_socket = IO::Socket::IP->new({
+  my $socket = IO::Socket::IP->new({
     PeerAddr => $host,
     PeerPort => $port
   });
   
   # Server Socket
-  my $io_socket = IO::Socket::IP->new({
+  my $socket = IO::Socket::IP->new({
     LocalAddr => 'localhost',
     LocalPort => 9000,
     Listen    => 5,
@@ -30,7 +29,7 @@ SPVM::IO::Socket::IP - IPv4/IPv6 Sockets
   # IPv6 Client Socket
   my $host = "google.com";
   my $port = 80;
-  my $io_socket = IO::Socket::IP->new({
+  my $socket = IO::Socket::IP->new({
     PeerAddr => $host,
     PeerPort => $port,
     Domain => SOCKET->AF_INET6,
@@ -38,7 +37,7 @@ SPVM::IO::Socket::IP - IPv4/IPv6 Sockets
 
 =head1 Description
 
-IO::Socket::INET class in L<SPVM> has methods to create IPv4/IPv6 Sockets.
+IO::Socket::INET class in L<SPVM> represents an IPv4 or IPv6 socket.
 
 =head1 Super Class
 
@@ -68,7 +67,7 @@ A peer address.
 
 C<has PeerPort : protected int;>
 
-A peer port
+A peer port.
 
 =head2 ReuseAddr
 
@@ -94,53 +93,23 @@ If this field is a true value, The L<SO_BROADCAST|https://linux.die.net/man/3/se
 
 C<static method new : L<IO::Socket::IP|SPVM::IO::Socket::IP> ($options : object[] = undef);>
 
-Creates a new L<IO::Socket::IP|SPVM::IO::Socket::IP> object.
+Creates a new L<IO::Socket::IP|SPVM::IO::Socket::IP> object given the options $options, and returns it.
 
-And creates a socket.
+This object represents a IPv4 or IPv6 domain socket.
 
-And if L</"PeerAddr"> field is defined, L<connect|https://linux.die.net/man/2/connect> is executed.
+If L</"ReuseAddr"> field is a true value, 1 is set to C<SO_REUSEADD> option of this socket.
 
-And if L</"LocalPort"> field is defined, L<bind|https://linux.die.net/man/2/bind> and L<listen|https://linux.die.net/man/2/listen> are executed.
+If L</"ReusePort"> field is a true value, 1 is set to C<SO_REUSEPORT> option of this socket.
 
-And returns the new object.
+If L</"Broadcast"> field is a true value, 1 is set to C<SO_BROADCAST> option of this socket.
 
-Options:
+If L</"Peer"> field is specified, this object becomes a client socket. It calls L<connect|SPVM::IO::Socket/"connect"> method.
 
-The following options are available adding the options for L<IO::Socket#new|SPVM::IO::Socket/"new"> method are available.
+If L</"Listen"> field is a positive value, this object becomes a server socket. It calls L<bind|SPVM::IO::Socket/"bind"> method and L<listen|SPVM::IO::Socket/"listen"> method.
 
-=over 2
+See L</"init"> method about the options $options.
 
-=item * C<ReuseAddr> : string
-
-L</"ReuseAddr"> field is set to this value.
-
-=item * C<ReusePort> : Int
-
-L</"ReusePort"> field is set to this value.
-
-=item * C<Broadcast> : Int
-
-L</"Broadcast"> field is set to this value.
-
-=item * C<PeerAddr> : string
-
-A peer address.
-
-L</"PeerAddr"> field is set to this value.
-
-=item * C<PeerPort> : Int
-
-L</"PeerPort"> field is set to this value.
-
-=item * C<LocalAddr> : string
-
-L</"LocalAddr"> field is set to this value.
-
-=item * C<LocalPort> : Int
-
-L</"LocalPort"> field is set to this value.
-
-=back
+The blocking mode of the socket is set to non-blocking mode.
 
 =head1 Instance Methods
 
@@ -148,7 +117,57 @@ L</"LocalPort"> field is set to this value.
 
 C<protected method init : void ($options : object[] = undef);>
 
-Initializes this instance.
+Initializes fields of this instance given the option $options.
+
+Options:
+
+The following options are available adding the options for L<IO::Socket#init|SPVM::IO::Socket/"init"> method are available.
+
+[Name][Type][Default Value]
+
+=over 2
+
+=item * C<ReuseAddr> : string = undef
+
+L</"ReuseAddr"> field is set to this value.
+
+=item * C<ReusePort> : Int = 0
+
+L</"ReusePort"> field is set to this value.
+
+=item * C<Broadcast> : Int = 0
+
+L</"Broadcast"> field is set to this value.
+
+=item * C<PeerAddr> : string = undef
+
+L</"PeerAddr"> field is set to this value.
+
+=item * C<PeerPort> : Int = 0
+
+L</"PeerPort"> field is set to this value.
+
+=item * C<LocalAddr> : string = undef
+
+L</"LocalAddr"> field is set to this value.
+
+=item * C<LocalPort> : Int = 0
+
+L</"LocalPort"> field is set to this value.
+
+=back
+
+L<Domain|IO::Socket#Domain> field is set to C<AF_INET> if C<Domain> option is not specified.
+
+L<Proto|IO::Socket#Proto> field is set to C<IPPROTO_TCP> if C<Proto> option is not specified.
+
+L<Type|IO::Socket#Type> field is set to the following value according to the value of L<Proto|IO::Socket#Type> field.
+
+If the value of C<Proto> is C<IPPROTO_TCP>, the C<Type> field is set to C<SOCK_STREAM>.
+
+If the value of C<Proto> is C<IPPROTO_UDP>, the C<Type> field is set to C<SOCK_DGRAM>.
+
+If the value of C<Proto> is C<IPPROTO_ICMP>, the C<Type> field is set to C<SOCK_RAW>.
 
 =head2 sockaddr
 
@@ -176,6 +195,8 @@ C<method sockport : int ();>
 
 Returns the local port.
 
+Implementation:
+
 If L</"Domain"> field is C<AF_INET>, this method calls L<IO::Socket::IP::Import::IPv4#sockport|IO::Socket::IP::Import::IPv4/"sockport"> method.
 
 If L</"Domain"> field is C<AF_INET6>, this method calls L<IO::Socket::IP::Import::IPv6#sockport|IO::Socket::IP::Import::IPv6/"sockport"> method.
@@ -186,6 +207,8 @@ C<method peeraddr : L<Sys::Socket::In_addr_base|SPVM::Sys::Socket::In_addr_base>
 
 Return the peer address.
 
+Implementation:
+
 If L</"Domain"> field is C<AF_INET>, this method calls L<IO::Socket::IP::Import::IPv4#peeraddr|IO::Socket::IP::Import::IPv4/"peeraddr"> method.
 
 If L</"Domain"> field is C<AF_INET6>, this method calls L<IO::Socket::IP::Import::IPv6#peeraddr|IO::Socket::IP::Import::IPv6/"peeraddr"> method.
@@ -196,6 +219,8 @@ C<method peerhost : string ();>
 
 Returns the peer host name.
 
+Implementation:
+
 If L</"Domain"> field is C<AF_INET>, this method calls L<IO::Socket::IP::Import::IPv4#peerhost|IO::Socket::IP::Import::IPv4/"peerhost"> method.
 
 If L</"Domain"> field is C<AF_INET6>, this method calls L<IO::Socket::IP::Import::IPv6#peerhost|IO::Socket::IP::Import::IPv6/"peerhost"> method.
@@ -206,6 +231,8 @@ C<method peerport : int ();>
 
 Returns the peer port.
 
+Implementation:
+
 If L</"Domain"> field is C<AF_INET>, this method calls L<IO::Socket::IP::Import::IPv4#peerport|IO::Socket::IP::Import::IPv4/"peerport"> method.
 
 If L</"Domain"> field is C<AF_INET6>, this method calls L<IO::Socket::IP::Import::IPv6#peerport|IO::Socket::IP::Import::IPv6/"peerport"> method.
@@ -214,7 +241,7 @@ If L</"Domain"> field is C<AF_INET6>, this method calls L<IO::Socket::IP::Import
 
 C<method accept : L<IO::Socket::IP|SPVM::IO::Socket::IP> ($peer_ref : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>[] = undef);>
 
-Calls L<accept|SPVM::IO::Socke/"new"> method of its super class given the argument given to this method and returns its return value.
+This method is the same as L<accept|SPVM::IO::Socket/"accept"> method, but its return type is different.
 
 =head1 Well Known Child Classes
 
@@ -226,6 +253,14 @@ Calls L<accept|SPVM::IO::Socke/"new"> method of its super class given the argume
 
 =back
 
+=head2 See Also
+
+=over 2
+
+=item * L<SPVM::IO::Socket::UNIX>
+
+=back
+
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
